  WSGIappLocaleSet()->setLocaleString("EUCJP","","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","A3:WSSTR Can not create class: %s.\nPlease check the import library is right.","饹 %s Ǥޤ\nɲåݡ꤬ͥǧƤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","B3:WSSTR The name %s is already used by another instance.","֥ %s ¾ΤΤ̾ΤŤʤäƤޤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","C3:WSSTR Normal:0:,Invisible:4:,Deleted:1:,Default changed:2:,Hidden:3:","̾:0:,ԲĻ:4:,:1:,ѹ:2:,ԲĻ벽ѹ:3:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","D3:WSSTR Target class:","Ͽоݥ饹:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","E3:WSSTR Property name:","ץѥƥ̾:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","F3:WSSTR Property type:","ץѥƥ:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","G3:WSSTR Variable name:","ѿ̾:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","H3:WSSTR Default value:","ǥե:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","I3:WSSTR Attribute:","°:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","J3:WSSTR Builder title:","ӥȥ:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","K3:WSSTR Select menu:",":");
  WSGIappLocaleSet()->setLocaleString("EUCJP","L3:WSSTR Warning","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","M3:WSSTR Invalid property name.\nPlease specify another name like WSNxxxx...","WSN ǻϤޤץѥƥ̾\nꤷƤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","N3:WSSTR Invalid variable name...","ѿ̾ꤷƤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","O3:WSSTR This name is already used by another procedure...","ꤵ줿̾Τץؿ̾\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","P3:WSSTR This name is already used by another external instance.","ꤵ줿̾Τ¾γ֥̾Τ\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","Q3:WSSTR This name is already used by another external instance array.","ꤵ줿̾Τ¾γ֥̾Τ\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","R3:WSSTR This property name is already used by another property.","ץѥƥ̾ʣƤޤ\nۤʤ̾ΤˤƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","S3:WSSTR The variable is already used.","ѿʣƤޤ\nۤʤΤꤷƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","T3:WSSTR Create","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","U3:WSSTR Please specify the target class window.","оݥ饹ɥꤷƤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","V3:WSSTR Please select the property.","ץѥƥ򤷤Ƥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Question","ǧ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X3:WSSTR Is it OK to delete the property?","ץѥƥƤǤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","Y3:WSSTR Update","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","Z3:WSSTR Create new property","ץѥƥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","a3:WSSTR Edit property","ץѥƥѹ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","b3:WSSTR Delete property","ץѥƥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","c3:WSSTR Type,Property name,Member name,Attribute,Default value",",ץѥƥ̾,̾,°,ǥե");
  WSGIappLocaleSet()->setLocaleString("EUCJP","d3:WSSTR New:NEW:,Edit:EDIT:,Delete:DEL:",":NEW:,Խ:EDIT:,:DEL:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","e3:WSSTR  Use the handler defined by user","桼ˤϥɥؿ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","f3:WSSTR (Normal)","(̾)");
  WSGIappLocaleSet()->setLocaleString("EUCJP","g3:WSSTR (Deleted)","()");
  WSGIappLocaleSet()->setLocaleString("EUCJP","h3:WSSTR (DefaultChanged)","(ѹ)");
  WSGIappLocaleSet()->setLocaleString("EUCJP","i3:WSSTR (Hidden)","(ԲĻ벽ѹ)");
  WSGIappLocaleSet()->setLocaleString("EUCJP","j3:WSSTR (Invisible)","(ԲĻ°)");
  WSGIappLocaleSet()->setLocaleString("EUCJP","k3:WSSTR Normal Def.:0:,Delete Def.:1:","̾:0:,ȥꥬκ:1:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Target class:","Ͽоݥ饹:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","m3:WSSTR Trigger name:","ȥꥬ̾:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","n3:WSSTR Define name:","ǥեʸ:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","o3:WSSTR Define value:","ǥե:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p3:WSSTR Define type:","°:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","q3:WSSTR Invalid trigger name.","ڡޤޤʤȥꥬ̾\nꤷƤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","r3:WSSTR Invalid define string...","ǥեʸꤷƤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","s3:WSSTR Please specify the define value > 31.","32 ʾͤꤷƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","t3:WSSTR This trigger name is already used by another one.","ȥꥬ̾ʣƤޤ\nۤʤ̾ΤˤƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","u3:WSSTR The define string is already used.","ǥեʸ󤬽ʣƤޤ\nۤʤΤꤷƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","v3:WSSTR The value is already used.","ꤷͤʣƤޤ\nۤʤΤꤷƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","w3:WSSTR Please select the trigger.","ȥꥬ򤷤Ƥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","x3:WSSTR Is it OK to delete the trigger?","ȥꥬƤǤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","y3:WSSTR Create new trigger","ȥꥬ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","z3:WSSTR Edit trigger","ȥꥬѹ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","A3:WSSTR Delete trigger","ȥꥬ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","B3:WSSTR Trigger Name,Trigger def,Trigger value,Attribute","ȥꥬ̾,ǥեʸ,ǥե,°");
  WSGIappLocaleSet()->setLocaleString("EUCJP","C3:WSSTR New:NEW:,Edit:EDIT:,Delete:DEL:",":NEW:,Խ:EDIT:,:DEL:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","D3:WSSTR All:",":");
  WSGIappLocaleSet()->setLocaleString("EUCJP","E3:WSSTR R:",":");
  WSGIappLocaleSet()->setLocaleString("EUCJP","F3:WSSTR G:",":");
  WSGIappLocaleSet()->setLocaleString("EUCJP","G3:WSSTR B:",":");
  WSGIappLocaleSet()->setLocaleString("EUCJP","H3:WSSTR Color:",":");
  WSGIappLocaleSet()->setLocaleString("EUCJP","I3:WSSTR Name:","̾:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","J3:WSSTR Add user color","桼ɲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","K3:WSSTR Edit user color","桼Խ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","L3:WSSTR Delete user color","桼κ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","M3:WSSTR Default colors,Standard colors,User defined colors","ǥեȿ,ɿ,桼");
  WSGIappLocaleSet()->setLocaleString("EUCJP","N3:WSSTR Please select the user color.","Խ桼򤷤Ƥ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","O3:WSSTR Delete the selected color: ","򤵤줿: ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","P3:WSSTR  ?"," ޤ?");
  WSGIappLocaleSet()->setLocaleString("EUCJP","Q3:WSSTR Please select the user color to delete.","桼򤷤Ƥ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","R3:WSSTR %s:DISP:,Save:SAVE:,Search:SEARCH:,SP,Compile:COMP:,%s:PRJ:,SP,Copy:COPY:,Paste:PASTE:,SP,Delete:DEL:","%s:DISP:,¸:SAVE:,:SEARCH:,SP,ѥ:COMP:,%s:PRJ:,SP,ʣ:COPY:,Žդ:PASTE:,SP,:DEL:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","S3:WSSTR Files,Instances,Properties,Procedures,Attributes","ե,󥹥,ץѥƥ,ץ,");
  WSGIappLocaleSet()->setLocaleString("EUCJP","T3:WSSTR Name,Class","̾,饹");
  WSGIappLocaleSet()->setLocaleString("EUCJP","U3:WSSTR None:NONE:","ʤ:NONE:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","V3:WSSTR Display","ɽ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Add to project","ץȤϿ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X3:WSSTR Dismiss","ɽ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","Y3:WSSTR Remove from project","ץȤϿ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","Z3:WSSTR Add procedure","ץɲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","a3:WSSTR Properties","ץ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","b3:WSSTR Edit procedure","ץԽ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","c3:WSSTR Delete procedure","ץκ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","d3:WSSTR Instance:","Ͽоݥ֥:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","e3:WSSTR Procedure name:","ץ̾:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","f3:WSSTR Trigger:","ưȥꥬ:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","g3:WSSTR Function name:","ưؿ̾:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","h3:WSSTR Invalid procedure name...","ץ̾ꤷƤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","i3:WSSTR Invalid function name...","ؿ̾ꤷƤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","j3:WSSTR Invalid procedure name...","ץ̾ꤷƤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","k3:WSSTR Invalid procedure name.\nAlready used by another procedure name.","ꤵ줿̾Τץؿ̾\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Invalid procedure name.\nAlready used by another instance name.","ꤵ줿̾Τ¾γ֥̾Τ\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","m3:WSSTR Invalid procedure name.\nAlready used by another instance array name.","ꤵ줿̾Τ¾γ֥̾Τ\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","n3:WSSTR Invalid function name.","ѿΤߤؿ̾ꤷƤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","o3:WSSTR Create %s.cpp...","%s.cpp\nޤ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p3:WSSTR Create %s/%s.cpp...","%s/%s.cpp\nޤ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","o3:WSSTR Create %s.rb...","%s.rb\nޤ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p3:WSSTR Create %s/%s.rb...","%s/%s.rb\nޤ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","o3:WSSTR Create %s.py...","%s.py\nޤ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p3:WSSTR Create %s/%s.py...","%s/%s.py\nޤ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","o3:WSSTR Create %s.pl...","%s.pl\nޤ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p3:WSSTR Create %s/%s.pl...","%s/%s.pl\nޤ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","q3:WSSTR Overwrite existing file: %s?","%s\n¸ߤޤ֤ޤ?");
  WSGIappLocaleSet()->setLocaleString("EUCJP","r3:WSSTR OK","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","s3:WSSTR Please specify a target instance.","оݥ֥ȤꤷƤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","t3:WSSTR Please select a procedure.","ץ򤷤Ƥ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","u3:WSSTR The procedure does not exist.","ꤵ줿ץ¸ߤޤǤ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","v3:WSSTR Delete this procedure?","ץƤǤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","w3:WSSTR Procedure name,Trigger,Function name","ץ̾,ȥꥬ,ؿ̾");
  WSGIappLocaleSet()->setLocaleString("EUCJP","x3:WSSTR File...","ե");
  WSGIappLocaleSet()->setLocaleString("EUCJP","y3:WSSTR Template","Ҥʷ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","z3:WSSTR Internal","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","A3:WSSTR New:NEW:,Properties:SET:,Edit procedure:EDIT:,Delete procedure:DEL:",":NEW:,ץ:SET:,ǥԽ:EDIT:,:DEL:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","B3:WSSTR done.\n","λޤ.\n");
  WSGIappLocaleSet()->setLocaleString("EUCJP","C3:WSSTR Break","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","D3:WSSTR Defaults,Environments,Imports,Compiling,Linking,Fonts,Etc..","ǥե,Ķ,ɲ,ѥ,,ե,");
  WSGIappLocaleSet()->setLocaleString("EUCJP","E3:WSSTR Default colors","ǥեȿ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","F3:WSSTR Default size","ǥե礭");
  WSGIappLocaleSet()->setLocaleString("EUCJP","G3:WSSTR Grid size","åɻ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","H3:WSSTR :Horizontal",":ؼ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","I3:WSSTR :Vertical",":ټ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","J3:WSSTR Base Window","ɥΥ١");
  WSGIappLocaleSet()->setLocaleString("EUCJP","K3:WSSTR Import Libraries","ɲåݡͥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","L3:WSSTR Add","ɲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","M3:WSSTR Delete","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","N3:WSSTR Terminal","ߥʥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","O3:WSSTR Source editor","ǥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","O3:WSSTR Editor options","ǥץ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","P3:WSSTR Web browser","Web֥饦");
  WSGIappLocaleSet()->setLocaleString("EUCJP","Q3:WSSTR Include path","̥󥯥롼ɥѥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","R3:WSSTR Compiler flags","̥ѥե饰");
  WSGIappLocaleSet()->setLocaleString("EUCJP","S3:WSSTR Compile mode","ѥˡ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","T3:WSSTR  Debug mode"," ǥХå⡼");
  WSGIappLocaleSet()->setLocaleString("EUCJP","U3:WSSTR Class library","饹饤֥");
  WSGIappLocaleSet()->setLocaleString("EUCJP","V3:WSSTR  Generate class library"," 饹饤֥ˤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Compiler","ѥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode","̾⡼,ǥХå⡼,̾凉ƥå⡼,ǥХåƥå⡼");
  WSGIappLocaleSet()->setLocaleString("EUCJP","Y3:WSSTR Include path","̥󥯥롼ɥѥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","Z3:WSSTR Compiler flags","̥ѥե饰");
  WSGIappLocaleSet()->setLocaleString("EUCJP","a3:WSSTR Include path","ǥХåѥ󥯥롼ɥѥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","b3:WSSTR Compiler flags","ǥХåѥѥե饰");
  WSGIappLocaleSet()->setLocaleString("EUCJP","c3:WSSTR Libraries","̥饤֥");
  WSGIappLocaleSet()->setLocaleString("EUCJP","d3:WSSTR Linker flags","̥󥫥ե饰");
  WSGIappLocaleSet()->setLocaleString("EUCJP","e3:WSSTR Linker","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","f3:WSSTR Debugger","ǥХå");
  WSGIappLocaleSet()->setLocaleString("EUCJP","f3:WSSTR Make","ᥤޥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","g3:WSSTR Runtime mode,Debug mode","̾⡼,ǥХå⡼");
  WSGIappLocaleSet()->setLocaleString("EUCJP","h3:WSSTR Libraries","̥饤֥");
  WSGIappLocaleSet()->setLocaleString("EUCJP","i3:WSSTR Output file","ϥե");
  WSGIappLocaleSet()->setLocaleString("EUCJP","j3:WSSTR Libraries","ǥХåѥ饤֥");
  WSGIappLocaleSet()->setLocaleString("EUCJP","k3:WSSTR Output file","ǥХåѽϥե");
  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Please select a target to delete.","оݤ򤷤Ƥ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","m3:WSSTR No-name","̾-");
  WSGIappLocaleSet()->setLocaleString("EUCJP","n3:WSSTR Name:WSN%s  Type:%s","̾:WSN%s  :%s");
  WSGIappLocaleSet()->setLocaleString("EUCJP","o3:WSSTR Invalid instance name.\nAlready used by another function name...","ꤵ줿̾Τץؿ̾\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p3:WSSTR Invalid instance name.\nAlready used by another instance name...","ꤵ줿̾Τ¾Υ֥̾Τ\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","q3:WSSTR Invalid instance name.\nAlready used by another instance array name...","ꤵ줿̾Τ¾̾ΤȽŤʤäƤޤΤ\nѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","r3:WSSTR Invalid instance name.\nAlready used by project name or something...","ꤵ줿̾ΤץȤʤɤ̾Τ\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","s3:WSSTR Can not use array name for application window.","ץꥱ󥦥ɥФ̾ΤϻȤޤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","t3:WSSTR Can not use array name for class window.","饹ɥǤϻȤޤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","u3:WSSTR Invalid instance name.\nAlready used by another procedure name...","ꤵ줿̾Τץؿ̾\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","v3:WSSTR Invalid instance name.\nAlready used by another external instance name...","ꤵ줿̾Τ¾γ֥̾Τ\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","w3:WSSTR Invalid instance array name.\nAlready used by another window, or invalid type.","ꤵ줿̾Τ¾Υɥ̾ΤȽŤʤäƤ뤫\nޤϡפƤʤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","x3:WSSTR Invalid instance name.\nAlready used by project name or something...","ꤵ줿̾ΤץȤʤɤ̾Τ\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","y3:WSSTR Invalid instance name.","֥̾ΤꤷƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","z3:WSSTR This trigger already exists.","ꤵ줿ȥꥬ¸ߤޤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","A3:WSSTR This trigger already exists.","ꤵ줿ȥꥬ¸ߤޤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","B3:WSSTR Can not delete the fixed trigger.","ꤷȥꥬϺǤޤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","C3:WSSTR Please select a trigger to delete.","ȥꥬꤷƤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","D3:WSSTR BaseClass","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","E3:WSSTR Base","١");
  WSGIappLocaleSet()->setLocaleString("EUCJP","F3:WSSTR If you change window definition type,\nyou have to change the type of the event procedure.\nDo you continue?","פѹ\n٥ȥץηۤʤޤΤǡ\nѥ뤬̤ʤʤ礬ޤ³ޤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","G3:WSSTR If it makes the class definition window type into another type,\nit needs to change the type of the event procedure.\nDo you continue?","饹Υɥۤʤ륿פѹ\n٥ȥץηۤʤޤΤǡ\nѥ뤬̤ʤʤ礬ޤ³ޤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","H3:WSSTR inherit base instance: %s Not Found.\nPlease specify the correct instance name.","˻ꤷ󥹥: %s \n¸ߤޤ󥹥󥹤ꤷƤ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","I3:WSSTR Invalid name.\nAlready used by another event procedure.","ꤵ줿̾Τץؿ̾\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","J3:WSSTR Invalid name.\nAlready used by another instance name.","ꤵ줿̾Τ¾Υ֥̾Τ\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","K3:WSSTR Invalid name.\nAlready used by another instance array name.","ꤵ줿̾Τ¾̾ΤȽŤʤäƤޤΤ\nѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","L3:WSSTR Invalid name.\nAlready used by the project name or the other one.","ꤵ줿̾ΤץȤʤɤ¾̾Τ\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","M3:WSSTR Can not specify the array name for window.","ɥФ̾ΤϻȤޤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","N3:WSSTR Can not specify the array name for class definition window.","饹ɥǤϻȤޤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","O3:WSSTR Invalid name.\nAlready used by another event procedure.","ꤵ줿̾Τץؿ̾\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","P3:WSSTR Invalid name.\nAlready used by another external instance.","ꤵ줿̾Τ¾γ֥̾Τ\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","Q3:WSSTR Invalid array name.\nThe Array type differs from another one,or exists also another window.","ꤵ줿̾Τ¾ɥ̾ΤȽŤʤäƤ뤫\nޤϡפƤʤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","R3:WSSTR Invalid name.\nAlready used by the project name or the other one.","ꤵ줿̾ΤץȤʤɤ¾̾Τ\nŤʤäƤޤΤѹƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","S3:WSSTR Invalid instance name.","֥̾ΤꤷƲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","T3:WSSTR ClassName","饹̾");
  WSGIappLocaleSet()->setLocaleString("EUCJP","U3:WSSTR Normal window","̾復ɥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","V3:WSSTR Class definition","饹ɥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Use object store","ȥǽ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X3:WSSTR Type","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","Y3:WSSTR Settings","饹");
  WSGIappLocaleSet()->setLocaleString("EUCJP","Z3:WSSTR Properties","ץѥƥԽ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","a3:WSSTR Triggers","ȥꥬԽ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","b3:WSSTR UserTriggers","桼ȥꥬԽ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","c3:WSSTR Icon","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","d3:WSSTR Comment","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","e3:WSSTR Base","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","f3:WSSTR Name","̾");
  WSGIappLocaleSet()->setLocaleString("EUCJP","g3:WSSTR File name","ե̾");
  WSGIappLocaleSet()->setLocaleString("EUCJP","h3:WSSTR Access","°");
  WSGIappLocaleSet()->setLocaleString("EUCJP","i3:WSSTR Global variable","Х");
  WSGIappLocaleSet()->setLocaleString("EUCJP","j3:WSSTR Project","Ͽ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","k3:WSSTR Belong to this project","ץȤϿ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Member","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR ENCODING","η");
  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR COMPAT","TARGET");
  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Platform compatible","ץåȥեߴ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Look & Feel","Look & Feel");
  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Gradation","Gradation");
  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Gui Policy","ǣգɥݥꥷ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","N3:WSSTR PropertyEditor","ץѥƥǥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","N3:WSSTR PropertyName:","ץѥƥ̾:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","N3:WSSTR PropertyType:","ץѥƥ:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","N3:WSSTR PropertyValue:","ץѥƥ:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","N3:WSSTR broken.","Ǥޤ.");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR OBJS","ɲå֥");
  WSGIappLocaleSet()->setLocaleString("EUCJP","F3:WSSTR If you change class window name,\nyou have to reject your old source code\nand change the name of the event procedure.\nDo you continue?","饹̾ѹȡޤǤ˺ɤ\n٥ȥץѹʤƤϤʤޤ\n³ޤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR ColorBox","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR MessageBox","åܥå");
  WSGIappLocaleSet()->setLocaleString("EUCJP","j3:WSSTR RemoteClass","⡼ȵǽ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","k3:WSSTR Generates the virtual remote class","ۥ⡼ȥ饹");
  WSGIappLocaleSet()->setLocaleString("EUCJP","b3:WSSTR RemoteMethods","⡼ȥ᥽å");
  WSGIappLocaleSet()->setLocaleString("EUCJP","c3:WSSTR Return type,Method name","ͷ,᥽å̾");
  WSGIappLocaleSet()->setLocaleString("EUCJP","G3:WSSTR Parameters","ѥ᡼");
  WSGIappLocaleSet()->setLocaleString("EUCJP","c3:WSSTR Type,Name",",̾");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Add","ɲ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Del","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Up","ذư");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Down","ذư");
  WSGIappLocaleSet()->setLocaleString("EUCJP","E3:WSSTR Method name:","᥽å̾");
  WSGIappLocaleSet()->setLocaleString("EUCJP","F3:WSSTR Return value type:","ͷ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","H3:WSSTR Name/Type","̾/");
  WSGIappLocaleSet()->setLocaleString("EUCJP","R3:WSSTR The method name is already used.","ꤵ줿᥽å̾Τϴ˻ѤƤޤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","S3:WSSTR Invalid method name.","ʥ᥽å̾ΤǤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","V3:WSSTR Please select the method.","᥽åɤ򤷤Ƥ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","d3:WSSTR RemoteClassName:","ۥ⡼ȥ饹̾:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","d3:WSSTR BaseClassName:","ۥ⡼ȥ饹̾:");
  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Language","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","K3:WSSTR Edit...","...");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Name of the struct:","¤̾");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Name of the value:","̾");
  WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Value:","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","c3:WSSTR Name,Value","̾,");
  WSGIappLocaleSet()->setLocaleString("EUCJP","P3:WSSTR Ruby","Ruby");
  WSGIappLocaleSet()->setLocaleString("EUCJP","P3:WSSTR Ruby(DBG)","Ruby(DBG)");
  WSGIappLocaleSet()->setLocaleString("EUCJP","P3:WSSTR Python","Python");
  WSGIappLocaleSet()->setLocaleString("EUCJP","P3:WSSTR Python(DBG)","Python(DBG)");
  WSGIappLocaleSet()->setLocaleString("EUCJP","P3:WSSTR Perl","Perl");
  WSGIappLocaleSet()->setLocaleString("EUCJP","P3:WSSTR Perl(DBG)","Perl(DBG)");
  WSGIappLocaleSet()->setLocaleString("EUCJP","f3:WSSTR Static option","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Statically linked","ƥå(DLL ̵)");
  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Dynamically linked","ʥߥå(DLL )");
